==> chopsticks_1.16.0.zip: chopsticks/doc/chopsticks-vignette.R <==
###################################################
### chunk number 1: init
###################################################
#line 65 "chopsticks-vignette.Rnw"
require(chopsticks)
require(hexbin)
data(for.exercise)


###################################################
### chunk number 2: 
###################################################
#line 95 "chopsticks-vignette.Rnw"
show(snps.10)


###################################################
### chunk number 3: 
###################################################
#line 102 "chopsticks-vignette.Rnw"
summary(snp.support)


###################################################
### chunk number 4: 
###################################################
#line 114 "chopsticks-vignette.Rnw"
summary(subject.support)


###################################################
### chunk number 5: 
###################################################
#line 136 "chopsticks-vignette.Rnw"
summary(snps.10)


###################################################
### chunk number 6: 
###################################################
#line 142 "chopsticks-vignette.Rnw"
snpsum <- col.summary(snps.10)
summary(snpsum)


###################################################
### chunk number 7: plot-snpsum
###################################################
#line 150 "chopsticks-vignette.Rnw"
par(mfrow = c(1, 2))
hist(snpsum$MAF)
hist(snpsum$z.HWE)


###################################################
### chunk number 8: sample-qc
###################################################
#line 165 "chopsticks-vignette.Rnw"
sample.qc <- row.summary(snps.10)
summary(sample.qc)


###################################################
### chunk number 9: plot-outliners-qc
###################################################
#line 173 "chopsticks-vignette.Rnw"
par(mfrow = c(1, 1))
plot(sample.qc)


###################################################
### chunk number 10: outliers
###################################################
#line 182 "chopsticks-vignette.Rnw"
use <- sample.qc$Heterozygosity>0
snps.10 <- snps.10[use, ]
subject.support <- subject.support[use, ]


###################################################
### chunk number 11: if-case-control
###################################################
#line 194 "chopsticks-vignette.Rnw"
if.case <- subject.support$cc == 1
if.control <- subject.support$cc == 0


###################################################
### chunk number 12: sum-case-control
###################################################
#line 200 "chopsticks-vignette.Rnw"
sum.cases <- col.summary(snps.10[if.case, ])
sum.controls <- col.summary(snps.10[if.control, ])


###################################################
### chunk number 13: plot-summaries
###################################################
#line 206 "chopsticks-vignette.Rnw"
hb <- hexbin(sum.controls$Call.rate, sum.cases$Call.rate, xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 14: plot-freqs
###################################################
#line 215 "chopsticks-vignette.Rnw"
sp <- plot(hexbin(sum.controls$MAF, sum.cases$MAF, xbin=50))
hexVP.abline(sp$plot.vp, 0, 1, col="white")


###################################################
### chunk number 15: tests
###################################################
#line 234 "chopsticks-vignette.Rnw"
tests <- single.snp.tests(cc, data = subject.support, snp.data = snps.10)


###################################################
### chunk number 16: sum-tests
###################################################
#line 249 "chopsticks-vignette.Rnw"
summary(tests)


###################################################
### chunk number 17: use
###################################################
#line 265 "chopsticks-vignette.Rnw"
use <- snpsum$MAF > 0.01 & snpsum$z.HWE^2 < 200


###################################################
### chunk number 18: sum-use
###################################################
#line 272 "chopsticks-vignette.Rnw"
sum(use)


###################################################
### chunk number 19: subset-tests
###################################################
#line 277 "chopsticks-vignette.Rnw"
tests <- tests[use]
position <- snp.support[use, "position"]


###################################################
### chunk number 20: plot-tests
###################################################
#line 285 "chopsticks-vignette.Rnw"
p1 <- p.value(tests, df=1)
plot(hexbin(position, -log10(p1), xbin=50))


###################################################
### chunk number 21: qqplot
###################################################
#line 292 "chopsticks-vignette.Rnw"
chi2 <- chi.squared(tests, df=1)
qq.chisq(chi2,  df = 1)


###################################################
### chunk number 22: more-tests
###################################################
#line 317 "chopsticks-vignette.Rnw"
tests <- single.snp.tests(cc, stratum, data = subject.support,
     snp.data = snps.10)
tests <- tests[use]
p1 <- p.value(tests, df = 1)
plot(hexbin(position, -log10(p1), xbin=50))


###################################################
### chunk number 23: more-tests-qq
###################################################
#line 324 "chopsticks-vignette.Rnw"
chi2 <- chi.squared(tests, df=1)
qq.chisq(chi2, df = 1)


###################################################
### chunk number 24: ord
###################################################
#line 337 "chopsticks-vignette.Rnw"
ord <- order(p1)
top10 <- ord[1:10]
top10


###################################################
### chunk number 25: top-10
###################################################
#line 346 "chopsticks-vignette.Rnw"
names <- tests@snp.names
p1[top10]
names[top10]
position[top10]


###################################################
### chunk number 26: top10-local
###################################################
#line 359 "chopsticks-vignette.Rnw"
posord <- order(position)
position <- position[posord]
names <- names[posord]
local <- names[position > 9.6e+07 & position < 9.8e+07]


###################################################
### chunk number 27: ld-2mb
###################################################
#line 372 "chopsticks-vignette.Rnw"
snps.2mb <- snps.10[, local]
ld.2mb <- ld.snp(snps.2mb)


###################################################
### chunk number 28: top1
###################################################
#line 398 "chopsticks-vignette.Rnw"
cc <- subject.support$cc
stratum <- subject.support$stratum
top <- as(snps.10[, "rs870041"], "numeric")
glm(cc ~ top + stratum, family = "binomial")


###################################################
### chunk number 29: top2
###################################################
#line 407 "chopsticks-vignette.Rnw"
top2 <- as(snps.10[, "rs10882596"], "numeric")
glm(cc ~ top2 + stratum, family = "binomial")


###################################################
### chunk number 30: blocks
###################################################
#line 439 "chopsticks-vignette.Rnw"
blocks <- split(posord, cut(position, seq(100000, 135300000, 20000)))
bsize <- sapply(blocks, length)
table(bsize)
blocks <- blocks[bsize>0]  


###################################################
### chunk number 31: twentyfive
###################################################
#line 448 "chopsticks-vignette.Rnw"
posord[1:20]
blocks[1:5]


###################################################
### chunk number 32: blocks-use
###################################################
#line 458 "chopsticks-vignette.Rnw"
snps.use <- snps.10[, use]
remove(snps.10)


###################################################
### chunk number 33: mtests
###################################################
#line 465 "chopsticks-vignette.Rnw"
mtests <- snp.rhs.tests(cc ~ stratum, family = "binomial", 
     data = subject.support, snp.data = snps.use, tests = blocks)
summary(mtests)


###################################################
### chunk number 34: plot-mtests
###################################################
#line 478 "chopsticks-vignette.Rnw"
pm <- p.value(mtests)
plot(hexbin(-log10(pm), xbin=50))


###################################################
### chunk number 35: qqplot-mtests
###################################################
#line 491 "chopsticks-vignette.Rnw"
qq.chisq(-2 * log(pm), df = 2)

==> chopsticks_1.77.0.zip: chopsticks/doc/chopsticks-vignette.R <==
### R code from vignette source 'chopsticks-vignette.Rnw'

###################################################
### code chunk number 1: init
###################################################
library(chopsticks)
library(hexbin)
data(for.exercise)


###################################################
### code chunk number 2: chopsticks-vignette.Rnw:98-99
###################################################
show(snps.10)


###################################################
### code chunk number 3: chopsticks-vignette.Rnw:104-105
###################################################
summary(snp.support)


###################################################
### code chunk number 4: chopsticks-vignette.Rnw:116-117
###################################################
summary(subject.support)


###################################################
### code chunk number 5: chopsticks-vignette.Rnw:137-139
###################################################
snpsum <- summary(snps.10)
summary(snpsum)


###################################################
### code chunk number 6: plot-snpsum
###################################################
par(mfrow = c(1, 2))
hist(snpsum$MAF)
hist(snpsum$z.HWE)


###################################################
### code chunk number 7: sample-qc
###################################################
sample.qc <- row.summary(snps.10)
summary(sample.qc)


###################################################
### code chunk number 8: plot-outliners-qc
###################################################
par(mfrow = c(1, 1))
plot(sample.qc)


###################################################
### code chunk number 9: outliers
###################################################
use <- sample.qc$Heterozygosity>0
snps.10 <- snps.10[use, ]
subject.support <- subject.support[use, ]


###################################################
### code chunk number 10: if-case-control
###################################################
if.case <- subject.support$cc == 1
if.control <- subject.support$cc == 0


###################################################
### code chunk number 11: sum-case-control
###################################################
sum.cases <- summary(snps.10[if.case, ])
sum.controls <- summary(snps.10[if.control, ])


###################################################
### code chunk number 12: plot-summaries
###################################################
hb <- hexbin(sum.controls$Call.rate, sum.cases$Call.rate, xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, a=0, b=1, col="black")


###################################################
### code chunk number 13: plot-freqs
###################################################
sp <- plot(hexbin(sum.controls$MAF, sum.cases$MAF, xbin=50))
hexVP.abline(sp$plot.vp, a=0, b=1, col="white") 


###################################################
### code chunk number 14: tests
###################################################
tests <- single.snp.tests(cc, data = subject.support, snp.data = snps.10)


###################################################
### code chunk number 15: sum-tests
###################################################
summary(tests)


###################################################
### code chunk number 16: use
###################################################
use <- snpsum$MAF > 0.01 & snpsum$z.HWE^2 < 200


###################################################
### code chunk number 17: sum-use
###################################################
sum(use)


###################################################
### code chunk number 18: subset-tests
###################################################
tests <- tests[use, ]
position <- snp.support[use, "position"]


###################################################
### code chunk number 19: plot-tests
###################################################
p1 <- pchisq(tests$chi2.1df, df = 1, lower.tail = FALSE)
plot(hexbin(position, -log10(p1), xbin=50))


###################################################
### code chunk number 20: qqplot
###################################################
qq.chisq(tests$chi2.1df, df = 1)


###################################################
### code chunk number 21: more-tests
###################################################
tests <- single.snp.tests(cc, stratum, data = subject.support,
     snp.data = snps.10)
tests <- tests[use, ]
p1 <- pchisq(tests$chi2.1df, df = 1, lower.tail = FALSE)
plot(hexbin(position, -log10(p1), xbin=50))


###################################################
### code chunk number 22: more-tests-qq
###################################################
qq.chisq(tests$chi2.1df, df = 1)


###################################################
### code chunk number 23: ord
###################################################
ord <- order(p1)
top10 <- ord[1:10]
top10


###################################################
### code chunk number 24: top-10
###################################################
names <- rownames(tests)
p1[top10]
names[top10]
position[top10]


###################################################
### code chunk number 25: top10-local
###################################################
posord <- order(position)
position <- position[posord]
names <- names[posord]
local <- names[position > 9.6e+07 & position < 9.8e+07]


###################################################
### code chunk number 26: ld-2mb
###################################################
snps.2mb <- snps.10[, local]
ld.2mb <- ld.snp(snps.2mb)


###################################################
### code chunk number 27: top1
###################################################
attach(subject.support)
top <- snps.10[, "rs870041"]
top <- as.numeric(top)
glm(cc ~ top + stratum, family = "binomial")


###################################################
### code chunk number 28: top2-3
###################################################
top2 <- snps.10[, "rs7088765"]
top2 <- as.numeric(top2)
glm(cc ~ top2 + stratum, family = "binomial")
top3 <- snps.10[, "rs1916572"]
top3 <- as(top3, "numeric")
glm(cc ~ top3 + stratum, family = binomial)


###################################################
### code chunk number 29: blocks
###################################################
blocks <- split(posord, cut(position, seq(100000, 135300000, 20000)))
bsize <- sapply(blocks, length)
table(bsize)
blocks <- blocks[bsize>0]  


###################################################
### code chunk number 30: twentyfive
###################################################
posord[1:20]
blocks[1:5]


###################################################
### code chunk number 31: blocks-use
###################################################
snps.use <- snps.10[, use]
remove(snps.10)


###################################################
### code chunk number 32: mtests
###################################################
mtests <- snp.rhs.tests(cc ~ stratum, family = "binomial", 
     data = subject.support, snp.data = snps.use, tests = blocks)
summary(mtests)


###################################################
### code chunk number 33: plot-mtests
###################################################
pm <- pchisq(mtests$Chi.squared, mtests$Df, lower.tail = FALSE)
plot(hexbin(-log10(pm), xbin=50))


###################################################
### code chunk number 34: qqplot-mtests
###################################################
qq.chisq(-2 * log(pm), df = 2)
